# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_excel.py
# Author:       toast
# Datetime:     2024/9/7 上午11:02
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl

from self_copy.apiAutoTest_v3 import log
from self_copy.apiAutoTest_v3.common.read_json import read_json
from self_copy.apiAutoTest_v3.common.read_project_ini import ReadProjectIni
from self_copy.apiAutoTest_v3.common.read_user_ini import ReadUserIni
from self_copy.apiAutoTest_v3.data_config.settings import *


class ReadExcel:
    def __init__(self,user_dir_name):
        self.pro_ini = ReadProjectIni()
        user_ini = ReadUserIni(user_dir_name)
        case_data_path = user_ini.get_file_path(FILE_CASE)
        expect_data_path = user_ini.get_file_path(FILE_EXPECT)
        sql_data_path = user_ini.get_file_path(FILE_SQL)

        excel_path = user_ini.get_file_path(FILE_EXCEL)
        table_name = user_ini.get_table_name(TABLE_KEY)

        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            log.error(f"加载excel工作簿/获取excel工作表时产生错误，错误为：{e},excel的路径为：{excel_path}，工作表名称为：{table_name}")
            raise e

    def __get_cell_value(self,column,row):
        try:
            cell_value = self.ws[column + str(row)].value
        except Exception as e:
            log.error(f"获取单元格数据失败，错误为：{e},列号为：{column},行号为：{row}")
            raise e
        else:
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()

    def moduel_name(self,row):
        return self.__get_cell_value(MODULE,row)

    def api_name(self,row):
        return self.__get_cell_value(API,row)

    def case_url(self,row):
        path = self.__get_cell_value(URL,row)
        if path:
            return self.pro_ini.get_host(HOST_KEY)+path

    def case_req_method(self,row):
        return self.__get_cell_value(REQ_METHOD,row)

    def case_mime(self,row):
        mime = self.__get_cell_value(MIME,row)
        if mime:
            return mime.lower()

    def case_data(self,row):
        case_data_key = self.__get_cell_value(CASE_DATA,row)
        if case_data_key:
            module_name = self.moduel_name(row)
            api_name = self.api_name(row)
            return self.case_data_dict[module_name][api_name][case_data_key]

    def expect_data(self,row):
        expect_data_key = self.__get_cell_value(EXPECT_DATA,row)
        if expect_data_key:
            module_name = self.moduel_name(row)
            api_name = self.api_name(row)
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    def sql_data(self,row):
        sql_data_key = self.__get_cell_value(SQL_DATA,row)
        if sql_data_key:
            module_name = self.moduel_name(row)
            api_name = self.api_name(row)
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    def sql_type(self,row):
        sql_type = self.__get_cell_value(SQL_TYPE,row)
        if sql_type:
            return sql_type.lower()

    def update_data(self,row):
        return self.__get_cell_value(UPDATE_KEY,row)

    def case_title(self,row):
            return self.__get_cell_value(TITLE,row)

    def case_level(self,row):
            return self.__get_cell_value(LEVEL,row)

    def get_data(self):
        list_data = []
        for row in range(2,self.ws.max_row+1):
            module_name = self.moduel_name(row)
            api_name = self.api_name(row)
            title = self.case_title(row)
            level = self.case_level(row)
            url = self.case_url(row)
            method = self.case_req_method(row)
            mime = self.case_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_data = self.update_data(row)
            if url is not None and method is not None and expect_data is not None:
                list_data.append([module_name,api_name,title,level,url,method,mime,case_data,expect_data,sql_type,sql_data,update_data])

        return list_data

if __name__ == '__main__':
    E = ReadExcel('toast')
    print(E.sql_data(16))
    # print(E.get_data())